<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div class="content-aa">
 *
 * @package Sauna Lite
 */
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
  <meta charset="<?php bloginfo( 'charset' ); ?>">
  <meta name="viewport" content="width=device-width">
  <?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
  <?php if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open();
  } else {
    do_action( 'wp_body_open' );
  }?>
  <?php if(get_theme_mod('sauna_lite_preloader_hide',false)!= '' || get_theme_mod('sauna_lite_responsive_preloader_hide',false) != ''){ ?>
    <?php if(get_theme_mod( 'sauna_lite_preloader_type','center-square') == 'center-square'){ ?>
      <div class='preloader'>
        <div class='preloader-squares'>
          <div class='square'></div>
          <div class='square'></div>
          <div class='square'></div>
          <div class='square'></div>
        </div>
      </div>
    <?php }else if(get_theme_mod( 'sauna_lite_preloader_type') == 'chasing-square') {?>
      <div class='preloader'>
        <div class='preloader-chasing-squares'>
          <div class='square'></div>
          <div class='square'></div>
          <div class='square'></div>
          <div class='square'></div>
        </div>
      </div>
    <?php }?>
  <?php }?>
  <header role="banner">
    <a class="screen-reader-text skip-link" href="#main"><?php esc_html_e( 'Skip to content', 'sauna-lite' ); ?><span class="screen-reader-text"><?php esc_html_e( 'Skip to content', 'sauna-lite' );?></span></a>
    <div id="header">
      <div class="container">
        <div class="<?php if( get_theme_mod( 'sauna_lite_sticky_header', false) != '' || get_theme_mod('sauna_lite_responsive_sticky_header',false) != '') { ?> sticky-header<?php } else { ?>close-sticky <?php } ?>">
          <div class="row">
            <div class="col-lg-3 col-md-5 col-6 align-self-center">
              <div class="logo py-1 align-self-center">
                <?php if ( has_custom_logo() ) : ?>
                  <div class="site-logo"><?php the_custom_logo(); ?></div>
                <?php endif; ?>
                <?php if( get_theme_mod( 'sauna_lite_site_title',true) != '') { ?>
                  <?php $blog_info = get_bloginfo( 'name' ); ?>
                  <?php if ( ! empty( $blog_info ) ) : ?>
                    <?php if ( is_front_page() && is_home() ) : ?>
                      <h1 class="site-title p-0"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                    <?php else : ?>
                      <p class="site-title m-0"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                    <?php endif; ?>
                  <?php endif; ?>
                <?php }?>
                <?php if( get_theme_mod( 'sauna_lite_site_tagline',false) != '') { ?>
                  <?php
                  $description = get_bloginfo( 'description', 'display' );
                  if ( $description || is_customize_preview() ) :
                  ?>
                    <p class="site-description m-0">
                      <?php echo esc_html($description); ?>
                    </p>
                  <?php endif; ?>
                <?php }?>
              </div>
            </div>
            <div class="col-lg-9 col-md-7 col-6 align-self-center">
              <div class="menubox nav align-self-center">
                <?php ?>
                  <div class="toggle-menu responsive-menu py-3">
                    <button role="tab" onclick="sauna_lite_menu_open()"><i class="<?php echo esc_html(get_theme_mod('sauna_lite_responsive_open_menu_icon','fas fa-bars')); ?>"></i><?php echo esc_html( get_theme_mod('sauna_lite_open_menu_label', __('Open Menu','sauna-lite'))); ?><span class="screen-reader-text"><?php esc_html_e(get_theme_mod('sauna_lite_open_menu_label', __('Open Menu','sauna-lite'))); ?></span></button>
                  </div>
                  <div id="menu-sidebar" class="nav side-menu my-lg-1">
                    <nav id="primary-site-navigation" class="primary-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'sauna-lite' ); ?>">
                      <?php 
                        wp_nav_menu( array( 
                          'theme_location' => 'primary',
                          'container_class' => 'main-menu-navigation clearfix' ,
                          'menu_class' => 'clearfix',
                          'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
                          'fallback_cb' => 'wp_page_menu',
                        ) ); 
                      ?>
                      <a href="javascript:void(0)" class="closebtn responsive-menu" onclick="sauna_lite_menu_close()"><?php echo esc_html( get_theme_mod('sauna_lite_close_menu_label', __('Close Menu','sauna-lite'))); ?><i class="<?php echo esc_html(get_theme_mod('sauna_lite_responsive_close_menu_icon','fas fa-times'));?>"></i><span class="screen-reader-text"><?php esc_html_e( get_theme_mod('sauna_lite_close_menu_label', __('Close Menu','sauna-lite'))); ?></span></a>
                    </nav>
                  </div>
                <?php ?>
              </div>
            </div>
          </div>
        </div>
        <div class="clear"></div>
      </div>
    </div>
  </header>